
local MakePlayerCharacter = require "prefabs/player_common"


local assets = {
    Asset("SCRIPT", "scripts/prefabs/player_common.lua"),
}
local prefabs = {}

-- Custom starting items
local start_inv = {"hotdog_cooked",
	"ketchup",
	"ketchup",
	"ketchup",
	"ketchup",
	"ketchup",
}

-- When the character is revived from human
local function onbecamehuman(inst)
	-- Set speed when reviving from ghost (optional)
	inst.components.locomotor:SetExternalSpeedMultiplier(inst, "sans_speed_mod", 1)
end

local master_postinit = function(inst)
    inst:AddComponent("sanityaura")
    inst.components.sanityaura.aurafn = function(inst, observer)
        if observer.prefab == "thegreatpapyrus" then
            return TUNING.SANITYAURA_TINY
        end
        return 0
    end
end

local function onbecameghost(inst)
	-- Remove speed modifier when becoming a ghost
   inst.components.locomotor:RemoveExternalSpeedMultiplier(inst, "sans_speed_mod")
end

-- When loading or spawning the character
local function onload(inst)
    inst:ListenForEvent("ms_respawnedfromghost", onbecamehuman)
    inst:ListenForEvent("ms_becameghost", onbecameghost)

    if inst:HasTag("playerghost") then
        onbecameghost(inst)
    else
        onbecamehuman(inst)
    end
end


-- This initializes for both the server and client. Tags can be added here.
local common_postinit = function(inst) 
	-- Minimap icon
	inst.MiniMapEntity:SetIcon( "sans.tex" )
	-- Access to sansational recipes
		inst:AddTag("sansational")
end

-- Deals poison damage.
local function DoPoisonDamage(inst)
inst.components.health:DoDelta(-1, true, "poison")
--Blip for 1/3 of a second upon poison
inst.AnimState:SetMultColour(1,0,1,1)
	inst:DoTaskInTime(((TUNING.POISON_DPS)*.5), function(inst) inst.AnimState:SetMultColour(1,1,1,1) end)
end

-- OnAttackOther, deal poison damage every .33 seconds.
local function onattackother(inst, data)
if data.target and data.target.components.health and not data.target.components.health:IsDead() then
-- If config says false; no target players. 
if not data.target:HasTag("player") or not TUNING.PLAYER_POISON == false then
-- Can't already be poisoned.
if data.target.poisontask == nil then
-- If conditions met; deal DoPoisonDamage value 3 times per second.
data.target.poisontask = data.target:DoPeriodicTask(TUNING.POISON_DPS, DoPoisonDamage)
-- End poison damage @ 30 seconds. Deals 90 damage total (30 seconds * 1 damage * 3 times per second).
data.target.poisonwearofftask = data.target:DoTaskInTime(30, function(inst) inst.poisontask:Cancel() inst.poisontask = nil end)
			end
		end
	end
end


-- This initializes for the server only. Components are added here.
local master_postinit = function(inst)
	-- choose which sounds this character will play
	inst.soundsname = "sans"
	
	-- Uncomment if "wathgrithr"(Wigfrid) or "webber" voice is used
    --inst.talker_path_override = "dontstarve_DLC001/characters/"
	
	-- Stats	
	inst.components.health:SetMaxHealth(TUNING.SANS_HEALTH)
	inst.components.hunger:SetMax(130)
	inst.components.sanity:SetMax(195)
	
	inst.components.builder.science_bonus = 1
	
	inst.components.temperature.mintemp = 20
	
	local WalkSpeed = (TUNING.WILSON_WALK_SPEED * 1.5)
	local RunSpeed = (TUNING.WILSON_RUN_SPEED * 1.5)
	
	inst.components.locomotor.walkspeed = 5
	inst.components.locomotor.runspeed = 7
	
	-- Damage multiplier (optional)
    inst.components.combat.damagemultiplier = .25
	
	-- Hunger rate (optional)
	inst.components.hunger.hungerrate = 1 * TUNING.WILSON_HUNGER_RATE
	
	inst:ListenForEvent("onattackother", onattackother)

	inst.OnLoad = onload
    inst.OnNewSpawn = onload
	
		--sanity gain near pap
	inst:AddComponent("sanityaura")

inst.components.sanityaura.aurafn = function(inst, observer)

if observer.prefab == "thegreatpapyrus" then

return TUNING.SANITYAURA_TINY

end

return 0

end
end

return MakePlayerCharacter("sans", prefabs, assets, common_postinit, master_postinit, start_inv)

